@@ -8,7 +8,10 @@
 # ==================================================================
 
 from django.apps import AppConfig
+from django.utils.translation import gettext_lazy as _
 
 
 class DjangoKeloveDbConfig(AppConfig):
+    label = 'django_kelove_db'
     name = 'django_kelove_db'
+    verbose_name = _('Django Db 增强')
