@@ -10,6 +10,9 @@
 from django.urls import path
 
 from .views import MySQLDatabaseDoc
+from .apps import DjangoKeloveDbConfig
+
+app_name = DjangoKeloveDbConfig.name
 
 urlpatterns = [
     path('mysql', MySQLDatabaseDoc.as_view()),
