@@ -11,7 +11,7 @@ from django.shortcuts import render
 from django.views.generic import View
 
 from .backends.mysql.doc import Doc
-from .util import helper
+from . import helper
 
 
 class MySQLDatabaseDoc(View):
